@@ -1,12 +1,35 @@
 import logging
 
-from .orders.builder import OrderBuilder
+from .order_builder.builder import OrderBuilder
 
-from .headers import create_level_1_headers, create_level_2_headers
+from .headers.headers import create_level_1_headers, create_level_2_headers
 from .signer import Signer
 
-from .endpoints import CANCEL, CANCEL_ALL, CREATE_API_KEY, DELETE_API_KEY, DERIVE_API_KEY, GET_API_KEYS, GET_LAST_TRADE_PRICE, GET_ORDER, GET_ORDER_BOOK, LARGE_ORDERS, MARKET_ORDER_HISTORY, MID_POINT, OPEN_ORDERS, ORDER_HISTORY, POST_ORDER, PRICE, TIME, TRADE_HISTORY
-from .clob_types import ApiCreds, FilterParams, LimitOrderArgs, MarketOrderArgs, RequestArgs
+from .endpoints import (
+    CANCEL,
+    CANCEL_ALL,
+    CREATE_API_KEY,
+    DELETE_API_KEY,
+    DERIVE_API_KEY,
+    GET_API_KEYS,
+    GET_LAST_TRADE_PRICE,
+    GET_ORDER,
+    GET_ORDER_BOOK,
+    LARGE_ORDERS,
+    MID_POINT,
+    OPEN_ORDERS,
+    ORDER_HISTORY,
+    POST_ORDER,
+    PRICE,
+    TIME,
+    TRADE_HISTORY,
+)
+from .clob_types import (
+    ApiCreds,
+    FilterParams,
+    OrderArgs,
+    RequestArgs,
+)
 from .exceptions import PolyException
 from .http_helpers.helpers import add_query_params, delete, get, post
 from py_order_utils.config import get_contract_config
@@ -14,13 +37,21 @@ from .constants import L0, L1, L1_AUTH_UNAVAILABLE, L2, L2_AUTH_UNAVAILABLE
 
 
 class ClobClient:
-    def __init__(self, host, chain_id: int = None, key:str = None, creds:ApiCreds = None, signature_type: int = None, funder: str = None):
+    def __init__(
+        self,
+        host,
+        chain_id: int = None,
+        key: str = None,
+        creds: ApiCreds = None,
+        signature_type: int = None,
+        funder: str = None,
+    ):
         """
         Initializes the clob client
         The client can be started in 3 modes:
         1) Level 0: Requires only the clob host url
                     Allows access to open CLOB endpoints
-        
+
         2) Level 1: Requires the host, chain_id and a private key.
                     Allows access to L1 authenticated endpoints + all unauthenticated endpoints
 
@@ -34,14 +65,16 @@ class ClobClient:
         if chain_id:
             self.contract_config = get_contract_config(chain_id)
         if self.signer:
-            self.builder = OrderBuilder(self.signer, sig_type=signature_type, funder=funder)
+            self.builder = OrderBuilder(
+                self.signer, sig_type=signature_type, funder=funder
+            )
         self.logger = logging.getLogger(self.__class__.__name__)
 
     def get_address(self):
         """
         Returns the public address of the signer
         """
-        return self.signer.address if self.signer else None
+        return self.signer.address() if self.signer else None
 
     def get_collateral_address(self):
         """
@@ -71,15 +104,12 @@ class ClobClient:
         if self.contract_config:
             return self.contract_config.get_executor()
 
-    
-    
     def get_ok(self):
         """
         Health check: Confirms that the server is up
         Does not need authentication
         """
         return get("{}/".format(self.host))
-    
 
     def get_server_time(self):
         """
@@ -88,28 +118,28 @@ class ClobClient:
         """
         return get("{}{}".format(self.host, TIME))
 
-    def create_api_key(self, nonce : int = None):
+    def create_api_key(self, nonce: int = None):
         """
-        Creates a new CLOB API key for the given 
+        Creates a new CLOB API key for the given
         """
         self.assert_level_1_auth()
-        
+
         endpoint = "{}{}".format(self.host, CREATE_API_KEY)
-        headers= create_level_1_headers(self.signer, nonce)
-        
+        headers = create_level_1_headers(self.signer, nonce)
+
         creds = post(endpoint, headers=headers)
         self.logger.info(creds)
         return creds
 
-    def derive_api_key(self, nonce : int = None):
+    def derive_api_key(self, nonce: int = None):
         """
-        Derives an already existing CLOB API key for the given address and nonce 
+        Derives an already existing CLOB API key for the given address and nonce
         """
         self.assert_level_1_auth()
-        
+
         endpoint = "{}{}".format(self.host, DERIVE_API_KEY)
-        headers= create_level_1_headers(self.signer, nonce)
-        
+        headers = create_level_1_headers(self.signer, nonce)
+
         creds = get(endpoint, headers=headers)
         self.logger.info(creds)
         return creds
@@ -120,7 +150,7 @@ class ClobClient:
         Level 2 Auth required
         """
         self.assert_level_2_auth()
-        
+
         request_args = RequestArgs(method="GET", request_path=GET_API_KEYS)
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         return get("{}{}".format(self.host, GET_API_KEYS), headers=headers)
@@ -131,7 +161,7 @@ class ClobClient:
         Level 2 Auth required
         """
         self.assert_level_2_auth()
-        
+
         request_args = RequestArgs(method="DELETE", request_path=DELETE_API_KEY)
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         return delete("{}{}".format(self.host, DELETE_API_KEY), headers=headers)
@@ -155,22 +185,14 @@ class ClobClient:
         url = add_query_params("{}{}".format(self.host, LARGE_ORDERS), params)
         return get(url)
 
-    def create_limit_order(self, order_args: LimitOrderArgs):
+    def create_order(self, order_args: OrderArgs):
         """
-        Creates and signs a limit order
+        Creates and signs an order
         Level 2 Auth required
         """
         self.assert_level_2_auth()
 
-        return self.builder.create_limit_order(order_args)
-
-    def create_market_order(self, order_args: MarketOrderArgs):
-        """
-        Creates and signs a market order
-        Level 2 Auth required
-        """
-        self.assert_level_2_auth()
-        return self.builder.create_market_order(order_args)
+        return self.builder.create_order(order_args)
 
     def post_order(self, order):
         """
@@ -178,22 +200,19 @@ class ClobClient:
         """
         self.assert_level_2_auth()
         body = order.dict()
-        headers = create_level_2_headers(self.signer, self.creds, RequestArgs(method="POST", request_path=POST_ORDER, body=body))
+        headers = create_level_2_headers(
+            self.signer,
+            self.creds,
+            RequestArgs(method="POST", request_path=POST_ORDER, body=body),
+        )
         return post("{}{}".format(self.host, POST_ORDER), headers=headers, data=body)
 
-    def create_and_post_limit_order(self, order_args: LimitOrderArgs):
+    def create_and_post_order(self, order_args: OrderArgs):
         """
-        Utility function to create and publish a limit order
+        Utility function to create and publish an order
         """
-        lim = self.create_limit_order(order_args)
-        return self.post_order(lim)
-
-    def create_and_post_market_order(self, order_args: MarketOrderArgs):
-        """
-        Utility function to create and publish a market order
-        """
-        mkt = self.create_market_order(order_args)
-        return self.post_order(mkt)
+        ord = self.create_order(order_args)
+        return self.post_order(ord)
 
     def cancel(self, order_id):
         """
@@ -201,9 +220,7 @@ class ClobClient:
         Level 2 Auth required
         """
         self.assert_level_2_auth()
-        body = {
-            "orderID": order_id
-        }
+        body = {"orderID": order_id}
 
         request_args = RequestArgs(method="DELETE", request_path=CANCEL, body=body)
         headers = create_level_2_headers(self.signer, self.creds, request_args)
@@ -247,7 +264,7 @@ class ClobClient:
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         return get("{}{}".format(self.host, endpoint), headers=headers)
 
-    def get_trade_history(self, params: FilterParams=None):
+    def get_trade_history(self, params: FilterParams = None):
         """
         Fetches the trade history for a user
         Requires Level 2 authentication
@@ -257,7 +274,7 @@ class ClobClient:
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         url = add_query_params("{}{}".format(self.host, TRADE_HISTORY), params)
         return get(url, headers=headers)
-    
+
     def get_order_history(self, params: FilterParams = None):
         """
         Fetches order history for a user
@@ -269,23 +286,12 @@ class ClobClient:
         url = add_query_params("{}{}".format(self.host, ORDER_HISTORY), params)
         return get(url, headers=headers)
 
-    def get_market_order_history(self, params: FilterParams = None):
-        """
-        Fetches market order history for a user
-        Requires Level 2 Authentication
-        """
-        self.assert_level_2_auth()
-        request_args = RequestArgs(method="GET", request_path=MARKET_ORDER_HISTORY)
-        headers = create_level_2_headers(self.signer, self.creds, request_args)
-        url = add_query_params("{}{}".format(self.host, MARKET_ORDER_HISTORY), params)
-        return get(url, headers=headers)
-    
     def get_last_trade_price(self, token_id):
         """
         Fetches the last trade price token_id
         """
         return get("{}{}?market={}".format(self.host, GET_LAST_TRADE_PRICE, token_id))
-    
+
     def assert_level_1_auth(self):
         """
         Level 1 Poly Auth
@@ -293,7 +299,6 @@ class ClobClient:
         if self.mode < L1:
             raise PolyException(L1_AUTH_UNAVAILABLE)
 
-
     def assert_level_2_auth(self):
         """
         Level 2 Poly Auth
@@ -307,6 +312,3 @@ class ClobClient:
         if self.signer is not None:
             return L1
         return L0
-            
-
-
