@@ -7,16 +7,15 @@ class PolyException(Exception):
 
 
 class PolyApiException(PolyException):
-    
-    def __init__(self, resp: Response=None, error_msg= None):
-        assert(resp is not None or error_msg is not None)
+    def __init__(self, resp: Response = None, error_msg=None):
+        assert resp is not None or error_msg is not None
         if resp is not None:
             self.status_code = resp.status_code
             self.error_msg = self._get_message(resp)
         if error_msg is not None:
             self.error_msg = error_msg
             self.status_code = None
-    
+
     def _get_message(self, resp: Response):
         try:
             return resp.json()
@@ -24,7 +23,9 @@ class PolyApiException(PolyException):
             return resp.text
 
     def __repr__(self):
-        return "PolyApiException[status_code={}, error_message={}]".format(self.status_code, self.error_msg)
+        return "PolyApiException[status_code={}, error_message={}]".format(
+            self.status_code, self.error_msg
+        )
 
     def __str__(self):
-        return self.__repr__()
\ No newline at end of file
+        return self.__repr__()
